<?php

declare(strict_types=1);

namespace Dedi\SyliusMailAdminPlugin\Sender;

use Sylius\Component\Mailer\Provider\EmailProviderInterface;
use Sylius\Component\Mailer\Renderer\RenderedEmail;
use Sylius\Component\Mailer\Sender\Adapter\AdapterInterface;
use Sylius\Component\Mailer\Sender\SenderInterface;

class CustomMailSender implements SenderInterface
{
    private AdapterInterface $senderAdapterInterface;

    private EmailProviderInterface $provider;

    public function __construct(
        AdapterInterface $senderAdapterInterface,
        EmailProviderInterface $provider
    ) {
        $this->senderAdapterInterface = $senderAdapterInterface;
        $this->provider = $provider;
    }

    public function send(string $code, array $recipients, array $data = [], array $attachments = [], array $replyTo = []): void
    {
        $mail = $this->provider->getEmail($code);

        $renderedEmail = new RenderedEmail(
            $mail->getSubject(),
            $mail->getContent()
        );

        $this->senderAdapterInterface->send(
            $recipients,
            $mail->getSenderAddress(),
            $mail->getSenderName(),
            $renderedEmail,
            $mail,
            $data,
            $attachments,
            $replyTo
        );
    }
}
